utils::globalVariables(
  names = c(
    "gen_reps",
    "trait",
    "value",
    "median",
    "sd",
    "SD",
    "Mean",
    "miss",
    "data",
    "deltaT",
    "genotype",
    "loc_max",
    "opm",
    "res",
    "rownames_to_column",
    "slope",
    "t1",
    "t2",
    "time",
    "corrected",
    "intercept",
    "quantile",
    "label",
    "mat",
    "miss%",
    "name.x",
    "txtCol",
    "value.y",
    "dens",
    "sse",
    "DE",
    "DMC",
    "val",
    "coef",
    "trapezoid_area",
    "hat",
    "k",
    "param",
    "initials",
    "fixed_params",
    "t(fx_params)",
    "fx_params",
    "loc_max_at",
    "fevals",
    "xtime",
    ".fitted",
    "convergence",
    "sse.x",
    "sse.y",
    "MSE",
    "SSE",
    "metric",
    "plan",
    "multisession",
    "sequential",
    "i",
    "predicted.value",
    "std.error",
    "t value",
    "type",
    "parameter",
    "coefficient",
    "method",
    "solution",
    "var",
    "uid",
    "y",
    "x",
    "t_value",
    "rdf",
    "Pr(>|t|)",
    "ci_lower",
    "ci_upper",
    ".id",
    "BIC",
    "pos",
    "x_new",
    "std.error.p",
    "pi_lower",
    "pi_upper",
    "df",
    ".y",
    ".grp",
    "nobs",
    "logLik",
    "model",
    "name",
    "o_max",
    "o_min",
    "R2",
    "AIC",
    "p",
    "fn_name",
    ".resid",
    ".sigma"
  )
)
